from django import template
from django.forms import RadioSelect, CheckboxInput
from django.utils.translation import get_language, ugettext_lazy
register = template.Library()

@register.filter
def is_tuple(value):
    """Tell if this value is a tuple or not.

    @param value (obj): any object
    @return: True if value is a tuple
    """
    # XXX: we would like to have is_type with an argument instead, but it would
    # rely on a strange comparison - isinstance(value, arg) doesn't work here
    return type(value) == tuple

@register.filter
def is_radio(value):
    """Tell if this value is a RadioSelect or not.

    @param value (obj): any object
    @return: True if value is a RadioSelect
    """
    return type(value) == RadioSelect

@register.filter
def is_checkbox(value):
    """Tell if this value is a CheckboxInput or not.

    @param value (obj): any object
    @return: True if value is a CheckboxInput
    """
    return type(value) == CheckboxInput

@register.filter
def selected_label(select):
    """Return the label of the single selected option.
    
    @param select: a BoundField object bound to a Select with single choice.
    @return: unicode
    """
    for value, label in select.field.choices:
        if value == select.value():
            return label
    return None

@register.filter
def buffer(value, n):
    """Split values in sub-lists of n elements.

    @param value (list): a list object
    @return: a list containing sub-lists

    For example:

    >>> buffer(range(10), 2)
    [[0, 1], [2, 3], [4, 5], [6, 7], [8, 9]]

    >>> buffer(range(10), 3)
    [[0, 1, 2], [3, 4, 5], [6, 7, 8], [9]]

    >>> buffer(range(10), 4)
    [[0, 1, 2, 3], [4, 5, 6, 7], [8, 9]]
    """
    result = []
    index = 0
    while index < len(value):
        result.append(value[index:index + n])
        index += n
    return result

@register.filter
def metadata(data):
    """Return a string representation of a metadata dict.

    @param data (dict{__proxy__: unicode}): metadata dictionnary
    @return: unicode
    """
    if not data:
        return ""
    lang = get_language()
    sep = ugettext_lazy(': ')
    items = ["%s%s%s" % (key.translate(lang), sep, value) for key, value in data.iteritems()]
    return replace_language_tag("(%s)" % ', '.join(items))

@register.filter
def replace_language_tag(text):
    """Replace {{LANGUAGE_CODE}} by the current language code.

    @param text (unicode): text to process
    @return: unicode
    """
    return text.replace("{{LANGUAGE_CODE}}", get_language())
